#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2.1
visibility:           public
id:                   non-negative-0.1.2.1-BMi61Y8We9CIPiJNNmApvc
key:                  non-negative-0.1.2.1-BMi61Y8We9CIPiJNNmApvc
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  6b70438ca9d9546feb0329079a48be04
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/non-negative-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2.1-BMi61Y8We9CIPiJNNmApvc
depends:
    QuickCheck-2.15.0.1-5Y9HZXtqNX41xwYMFzmoSZ base-4.18.2.1
    utility-ht-0.0.17.2-7JeB7DsoB0DB67XpMDvpYk

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

